# OzNetNerd AWS Organisations

Convenience Python module for AWS Organisations & STS

# Documentation

Module documentation & examples can be found [here.](https://onnawsorgs.oznetnerd.com/)


# Contact

* Blog: [oznetnerd.com](https://oznetnerd.com)
* Email: will@oznetnerd.com